@@ -29,9 +29,8 @@ class PublicNode(object):
 
     def broadcast(self, transaction):
         from LTO import PyCLTO
-        data = json.dumps(transaction.toJson)
+        data = json.dumps(transaction.toJson())
         response = self.wrapper(api='/transactions/broadcast', postData=data)
-        print(response)
         return PyCLTO().fromData(response)
 
     def getScript(self, scriptSource):
